pub struct Relationship {
pub to: ItemId,
pub relationship_type: RelationshipType,
}Expand description
Represents a relationship from an Item to another item.
The source item is implied by the Item containing this relationship.
Fields
to: ItemIdTarget item ID.
relationship_type: RelationshipTypeType of relationship.
Implementations
Sourceimpl Relationship
impl Relationship
Sourcepub fn new(to: ItemId, relationship_type: RelationshipType) -> Self
pub fn new(to: ItemId, relationship_type: RelationshipType) -> Self
Creates a new relationship to the given target.
Sourcepub fn rel_type(&self) -> RelationshipType
pub fn rel_type(&self) -> RelationshipType
Returns the relationship type.