pub fn parse_document(
content: &str,
file_path: &Path,
repository: &Path,
) -> Result<ParsedDocument, ParseError>Expand description
Parses a Markdown file and returns the item and body.
pub fn parse_document(
content: &str,
file_path: &Path,
repository: &Path,
) -> Result<ParsedDocument, ParseError>Parses a Markdown file and returns the item and body.