pub struct DiffService;Expand description
Service for computing diffs between knowledge graph states.
Implementations
Sourceimpl DiffService
impl DiffService
Sourcepub fn diff(&self, opts: &DiffOptions) -> Result<DiffResult, DiffError>
pub fn diff(&self, opts: &DiffOptions) -> Result<DiffResult, DiffError>
Computes the diff between two references.
This method supports full Git reference comparison when the repository paths are Git repositories. It will parse the knowledge graph at each reference point and compute the differences.
Sourcepub fn diff_graphs(
&self,
old_graph: &KnowledgeGraph,
new_graph: &KnowledgeGraph,
ref1: impl Into<String>,
ref2: impl Into<String>,
) -> DiffResult
pub fn diff_graphs( &self, old_graph: &KnowledgeGraph, new_graph: &KnowledgeGraph, ref1: impl Into<String>, ref2: impl Into<String>, ) -> DiffResult
Computes the diff between two existing graphs.
Use this method when you already have the graphs loaded.